/*
 * Copyright Dept. of Mathematics & Computer Science Univ. Paris-Descartes
 *
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */

package pddl4j.forward;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import pddl4j.exp.AtomicFormula;

/**
 * This class implements a plan.
 * 
 * @author Damien Pellier
 * @version 1.0 
 */
public final class Plan implements Iterable<AtomicFormula> {
    
    /**
     * The flag used to indicate if the plan is solution.
     */
    private boolean isSolution;
    
    /**
     * The list 
     */
    private List<AtomicFormula> actions;

    /**
     * The default plan constructor.
     */
    public Plan() {
        super();
        this.isSolution = false;
        this.actions = new ArrayList<AtomicFormula>();
    }
    
    /**
     * Adds a new actions at the end of this plan.
     * 
     * @param a the action to be added.
     */
    public void add(AtomicFormula a) {
        this.actions.add(a);
    }
    
    /**
     * Returns <code>true</code> if the plan is solution.
     * 
     * @return <code>true</code> if the plan is solution; <code>false</code>
     *         otherwise.
     */
    public boolean isSolution() {
        return this.isSolution;
    }

    /**
     * Sets the solution flag of this plan to a specified value.
     * 
     * @param flag the value of the solution flag to be set.
     */
    public void setSolution(final boolean flag) {
        this.isSolution = flag;
    }

    /**
     * Returns an iterator over the action in this plan.
     * 
     * @return an iterator over the action in this plan.
     */
    public Iterator<AtomicFormula> iterator() {
        return this.actions.iterator();
    }
    
    /**
     * Returns <code>true</code> if this plan is equal to an other object.
     * 
     * @param obj the other object to be compared.
     * @return <code>true</code> if this plan is equal to an other object;
     *         <code>false</code> otherwise.
     */
    public boolean equals(Object obj) {
        if (obj != null && this.getClass().equals(obj.getClass())) {
            Plan other = (Plan) obj;
            return this.actions.equals(other.actions);
        }
        return false;
    }
    
    /**
     * Returns the hashcode value of this plan.
     * 
     * @return the hascode value of this plan.
     */
    public int hashCode() {
        return this.actions.hashCode();
    }
    
    /**
     * Returns a string representation of this plan.
     * 
     * @return a string representation of this plan.
     */
    public String toString() {
        StringBuffer str = new StringBuffer();
        int i = 0;
        for (AtomicFormula a : this) {
            str.append(i);
            str.append(". ");
            str.append(a.toString());
            str.append("\n");
            i++;
        }
        return str.toString();
    }
}
